ozi-new webui

### {TRANSLATION('adm-disclaimer-title')}

×

{disclaimer_text}

### {TRANSLATION('btn-options')}

×

{TRANSLATION('term-user-interface')} {TRANSLATION('opt-menu-language-text')}
{TRANSLATION('term-output')} {TRANSLATION('opt-menu-copyright-head-input')}

#####

{config['new']['copyright_head'] if config['new']['copyright_head'] else COPYRIGHT_HEAD}
{TRANSLATION('opt-menu-enable-cython').replace('$value', '')}
{TRANSLATION('opt-menu-enable-uv').replace('$value', '')}
{TRANSLATION('opt-menu-github-harden-runner').replace('$value', '')}
{TRANSLATION('opt-menu-update-wrapfile').replace('$value', '')}
{TRANSLATION('term-input')} {TRANSLATION('opt-menu-allow-file-input')}

#####

{', '.join(METADATA.spec.python.src.allow_files)}
{TRANSLATION('opt-menu-strict').replace('$value', '')}
{TRANSLATION('opt-menu-verify-email').replace('$value', '')}

# {TRANSLATION('web-core-metadata')}

{TRANSLATION('pro-name')}

#####

{TRANSLATION('pro-summary')}

#####

{TRANSLATION('pro-keywords')}

#####

{TRANSLATION('pro-author')}

#####

{TRANSLATION('pro-author-email')}

#####

{TRANSLATION('pro-maintainer')}

#####

{TRANSLATION('pro-maintainer-email')}

#####

{TRANSLATION('pro-project-urls-cbl')}

#####

{TRANSLATION('pro-requires-dist')}

#####

{TRANSLATION('pro-readme-type')}

#####

{TRANSLATION('pro-license-expression')}
{TRANSLATION('edit-menu-btn-license-exception')}
{TRANSLATION('pro-license')}
{TRANSLATION('edit-menu-btn-license-file')}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-status'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-language'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-audience'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-environment'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-framework'))}
{TRANSLATION('pro-classifier-cbl', key=TRANSLATION('edit-menu-btn-topic'))}
{TRANSLATION('adm-confirm')}